import { IRealmOptions } from "../../../shared";
import { League, IListOptions } from "../../../shared/leagues";
/**
 * @remarks
 * Requires [[Settings.serviceToken]] to be set and the scope `service:leagues`.
 *
 * @example
 * Get the list of the leagues that are currently active on the PlayStation realm.
 *
 * ```typescript
 * const data = await PathOfExile.OAuthAPI.Leagues.get({ type: "main", realm: "sony" });
 * ```
 *
 * @endpoint https://api.pathofexile.com/league
 * @param options
 * @throws [[APIError]]
 */
export declare const getAll: (options?: IListOptions) => Promise<League[]>;
/**
 * @remarks
 * Requires [[Settings.serviceToken]] to be set and the scope `service:leagues`.
 *
 * @example
 * Get the data from the Metamorph league.
 *
 * ```typescript
 * const data = await PathOfExile.OAuth.Leagues.getById("Metamorph");
 * ```
 *
 * @endpoint https://api.pathofexile.com/league/:id
 * @param id
 * @param options
 * @throws [[APIError]]
 */
export declare const getById: (id: string, options?: IRealmOptions) => Promise<League>;
