import { IRealmOptions } from "../../../shared";
import { CharacterBase, Character } from "../../../shared/characters";
import { InventoryItem } from "../../../shared/item";
import { Passives } from "../../../shared/passives";
/**
 * Returns a list of characters for a specific account.
 *
 * @remarks The profile has to be public.
 *
 * @endpoint https://pathofexile.com/character-window/get-characters
 * @param accountName The name of the account
 * @param options
 * @returns A list of characters of an account
 * @throws [[APIError]]
 */
export declare const getAll: (accountName: string, options?: IRealmOptions) => Promise<CharacterBase[]>;
/**
 * Returns a specific character from an account.
 *
 * @remarks
 * The profile has to be public.
 *
 * @param accountName The name of the account
 * @param name The character name
 * @endpoint https://pathofexile.com/character-window/get-items
 *         & https://pathofexile.com/character-window/get-passive-skills
 * @throws [[APIError]]
 */
export declare const getByName: (accountName: string, charName: string) => Promise<Character>;
/**
 * Returns the equipped & inventory items of a character.
 *
 * @remarks
 * The profile has to be public. Jewels in the passive skill tree are not included.
 *
 * @param accountName The name of the account
 * @param name The character name
 * @endpoint https://pathofexile.com/character-window/get-items
 * @throws [[APIError]]
 */
export declare const getItems: (accountName: string, charName: string) => Promise<InventoryItem[]>;
/**
 * Returns the passive skills of a character.
 *
 * @remarks
 * The profile has to be public. Bandit choice is not included.
 *
 * @param accountName The name of the account
 * @param name The character name
 * @endpoint https://pathofexile.com/character-window/get-passive-skills
 * @throws [[APIError]]
 */
export declare const getPassives: (accountName: string, charName: string) => Promise<Passives>;
