import { League } from "../../../shared/leagues";
import { PublicListOptions, LeagueOptions } from "./models";
/**
 * @example
 * Get the list of the leagues that are currently active on the PlayStation realm.
 *
 * ```typescript
 * const data = await PathOfExile.Public.Leagues.get({ type: "main", realm: "sony" });
 * ```
 *
 * @endpoint https://api.pathofexile.com/leagues
 * @param options
 * @throws [[APIError]]
 */
export declare const getAll: (options?: PublicListOptions) => Promise<League[]>;
/**
 * @example
 * Get the data from the Metamorph league, including the first 100 entries of the ladder.
 *
 * ```typescript
 * const data = await PathOfExile.Public.Leagues.getById("Metamorph", { ladder: 1, limit: 100 });
 * ```
 *
 * @endpoint https://api.pathofexile.com/leagues/:id
 * @param id
 * @param options
 * @throws [[APIError]]
 */
export declare const getById: (id: string, options?: LeagueOptions) => Promise<League>;
