import { Language } from "../../../shared";
import { TradeItemGroup } from "../../../shared/trade/items";
import { TradeLeague } from "../../../shared/trade/leagues";
import { ExchangeQueryContainer, ExchangeResults } from "../../../shared/trade/query/exchange";
import { FetchResult } from "../../../shared/trade/query/fetch";
import { SearchQueryContainer, SearchResult } from "../../../shared/trade/query/search";
import { Group } from "../../../shared/trade/static";
import { StatGroup } from "../../../shared/trade/stats";
/**
 * @endpoint https://pathofexile.com/api/trade/data/leagues
 * @param language: The language. Default: English
 *
 * @returns A list of currently active trade leagues.
 * @throws [[APIError]]
 */
export declare const getLeagues: (language?: Language) => Promise<TradeLeague[]>;
/**
 * @endpoint https://pathofexile.com/api/trade/data/stats
 * @param language: The language. Default: English
 *
 * @throws [[APIError]]
 */
export declare const getStats: (language?: Language) => Promise<StatGroup[]>;
/**
 * @endpoint https://pathofexile.com/api/trade/data/static
 * @param language: The language. Default: English
 *
 * @throws [[APIError]]
 */
export declare const getStatic: (language?: Language) => Promise<Group[]>;
/**
 *
 * @endpoint https://pathofexile.com/api/trade/data/items
 * @param language: The language. Default: English
 *
 * @returns A list of tradeable item bases including unique items.
 * @throws [[APIError]]
 */
export declare const getTradeItems: (language?: Language) => Promise<TradeItemGroup[]>;
/**
 *
 * @endpoint https://pathofexile.com/api/trade/data/fetch/:hashes
 *
 * @param hashes The hashes of the items to fetch
 *
 * @returns A collection of listed items with the provided hashes
 * @throws [[APIError]]
 */
export declare const fetch: (hashes: string[], query?: string) => Promise<FetchResult[]>;
/**
 * Execute a search query
 *
 * @endpoint https://www.pathofexile.com/api/trade/search/:league
 * @param league
 * @param query
 * @throws [[APIError]]
 */
export declare const search: (league: string, query: SearchQueryContainer) => Promise<SearchResult>;
/**
 * Execute an exchange query
 *
 * @endpoint https://www.pathofexile.com/api/trade/exchange/:league
 * @param league
 * @param query
 * @throws [[APIError]]
 */
export declare const exchange: (league: string, query: ExchangeQueryContainer) => Promise<ExchangeResults>;
