import { IRealmOptions } from "../../../shared";
import { CharacterBase, Character } from "../../../shared/characters";
import { InventoryItem } from "../../../shared/item";
import { Passives } from "../../../shared/passives";
/**
 * Returns a list of characters of the owning account.
 *
 * @remarks
 * Requires `sessionId` to be set in [[Settings]] if profile or character tab is private.
 *
 * @endpoint https://pathofexile.com/character-window/get-characters
 * @param options
 * @returns A list of characters of an account
 * @throws [[APIError]]
 */
export declare const getAll: (options?: IRealmOptions) => Promise<CharacterBase[]>;
/**
 * Returns a specific character from the owning account.
 *
 * @remarks
 * Requires `sessionId` to be set in [[Settings]] if profile or character tab is private.
 *
 * @param name The character name.
 * @endpoint https://pathofexile.com/character-window/get-items
 *         & https://pathofexile.com/character-window/get-passive-skills
 * @throws [[APIError]]
 */
export declare const getByName: (name: string) => Promise<Character>;
/**
 * Returns the equipped & inventory items of a character.
 *
 * @remarks
 * Requires `sessionId` to be set in [[Settings]] if profile or character tab is private.
 *
 * @param name The character name
 * @endpoint https://pathofexile.com/character-window/get-items
 * @throws [[APIError]]
 */
export declare const getItems: (charName: string) => Promise<InventoryItem[]>;
/**
 * Returns the passive skills of a character.
 *
 * @remarks
 * Requires `sessionId` to be set in [[Settings]] if profile or character tab is private.
 * Bandit choice is not included.
 *
 * @param name The character name
 * @endpoint https://pathofexile.com/character-window/get-passive-skills
 * @throws [[APIError]]
 */
export declare const getPassives: (charName: string) => Promise<Passives>;
