import { Transformable } from "../../../common/classes/Transformable";
import { Account } from "../accounts";
import { Character } from "./Character";
export declare abstract class CharacterBase extends Transformable {
    name: string;
    class: string;
    level: number;
    experience: number;
    league?: string;
    id?: string;
    expired?: boolean;
    deleted?: boolean;
    current?: boolean;
    /**
     * Returns the owning account of the character.
     *
     * @remarks For characters belonging to another account, the profile has to be public.
     * @throws [[APIError]]
     */
    getAccount?(): Promise<Account>;
    /**
     * Returns a character including equipment, inventory, and passives.
     *
     * @throws [[APIError]]
     */
    abstract getCharacter(): Promise<Character>;
    /**
     * Calculates the current level progression and returns it as a percentage value.
     */
    get levelProgression(): number;
}
