import { Transformable } from "../../../common/classes/Transformable";
import { Realm } from "../../shared";
import { Ladder } from "../ladders/Ladder";
import { ILadderOptions } from "../ladders/models/Options";
import { LeagueRule } from "./LeagueRule";
/**
 * League entity as defined in https://www.pathofexile.com/developer/docs/reference#type-League
 */
export declare abstract class League extends Transformable {
    id: string;
    realm?: Realm;
    url?: string;
    description?: string;
    rules?: LeagueRule[];
    registerAt?: Date;
    startAt?: Date;
    endAt?: Date;
    event?: boolean;
    timedEvent?: boolean;
    scoreEvent?: boolean;
    delveEvent?: boolean;
    ladder?: Ladder;
    /**
     * @remarks
     * If `store` is set to true the [[ladder]] property will be overwritten.
     *
     * @param options
     * @param store If set to `true`, the ladder will be saved in the [[ladder]] property
     * @returns The ladder for this league
     * @throws [[APIError]]
     */
    abstract getLadder<T extends ILadderOptions>(store: boolean, options?: T): Promise<Ladder>;
}
